==> magento-module-data-services-graphql-1.2.0.zip: Model/Resolver/StorefrontInstanceContext.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Magento\DataServicesGraphQl\Model\Resolver;

use Magento\DataServices\Model\VersionFinderInterface;
use Magento\Framework\App\CacheInterface;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Query\Resolver\ContextInterface;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Framework\UrlInterface;
use Magento\ServicesId\Model\ServicesConfigInterface;
use Magento\Customer\Api\Data\GroupInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Customer\Model\Session;
use Magento\Framework\App\Config\ScopeConfigInterface;

/**
 * Class that implements the dataServicesStorefrontInstanceContext resolver
 */
class StorefrontInstanceContext implements ResolverInterface
{

    /**
     * Extension constants
     */
    const CATALOG_EXPORTER_MODULE_NAME = 'Magento/CatalogDataExporter';
    const CATALOG_EXPORTER_PACKAGE_NAME = 'magento/saas-export';
    const CATALOG_EXPORTER_VERSION_CACHE_TAG = 'catalog_exporter_extension_version';

    /**
     * Service Connector Config Paths
     *
     * @var string
     */
    private const CONFIG_PATH_API_KEY = 'services_connector/services_connector_integration/production_api_key';

    /**
     * @var VersionFinderInterface
     */
    private $versionFinder;

    /**
     * @var ServicesConfigInterface
     */
    private $servicesConfig;

    /**
     * @var CacheInterface
     */
    private $cache;

    /**
     * @var Session
     */
    private Session $customerSession;

    /**
     * @var ScopeConfigInterface
     */
    private ScopeConfigInterface $scopeConfig;

    /**
     * StorefrontInstanceContext constructor.
     * @param VersionFinderInterface $versionFinder
     * @param ServicesConfigInterface $servicesConfig
     * @param CacheInterface $cache
     * @param Session $customerSession
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        VersionFinderInterface $versionFinder,
        ServicesConfigInterface $servicesConfig,
        CacheInterface $cache,
        Session $customerSession,
        ScopeConfigInterface $scopeConfig,
    ) {
        $this->versionFinder = $versionFinder;
        $this->servicesConfig = $servicesConfig;
        $this->cache = $cache;
        $this->customerSession = $customerSession;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @param Field $field
     * @param ContextInterface $context
     * @param ResolveInfo $info
     * @param array|null $value
     * @param array|null $args
     * @return array
     */
    public function resolve(
        Field $field,
        $context,
        ResolveInfo $info,
        array $value = null,
        array $args = null
    ) {
        $store = $context->getExtensionAttributes()->getStore();
        return [
            'environment_id' => $this->servicesConfig->getEnvironmentId(),
            'environment' => $this->servicesConfig->getEnvironmentType(),
            'ims_org_id' => $this->servicesConfig->getImsOrganizationId(),
            'store_url' => $store->getBaseUrl(UrlInterface::URL_TYPE_WEB),
            'website_id' => $store->getWebsiteId(),
            'website_code' => $store->getWebsite()->getCode(),
            'store_id' => $store->getGroup()->getId(),
            'store_code' => $store->getGroup()->getCode(),
            'store_view_id' => $store->getId(),
            'store_view_code' => $store->getCode(),
            'website_name' => $store->getWebsite()->getName(),
            'store_name' => $store->getGroup()->getName(),
            'store_view_name' => $store->getName(),
            'catalog_extension_version' => $this->getCatalogExtensionVersion(),
            'base_currency_code' => $store->getBaseCurrencyCode(),
            'store_view_currency_code' => $store->getCurrentCurrency()->getCode(),
            'customer_group' => $this->getCustomerGroupCode(),
            'api_key' => $this->getApiKey()
        ];
    }

    /**
     * Return catalog extension version
     *
     * @return string|null
     */
    private function getCatalogExtensionVersion(): ?string
    {
        $catalogVersion = $this->cache->load(self::CATALOG_EXPORTER_VERSION_CACHE_TAG);
        if (!$catalogVersion) {
            $catalogVersion = $this->versionFinder->getVersionFromComposer(self::CATALOG_EXPORTER_PACKAGE_NAME)
                ?: $this->versionFinder->getVersionFromFiles(
                    self::CATALOG_EXPORTER_MODULE_NAME,
                    self::CATALOG_EXPORTER_PACKAGE_NAME
                );
            $this->cache->save($catalogVersion, self::CATALOG_EXPORTER_VERSION_CACHE_TAG);
        }

        return $catalogVersion ?? null;
    }

    /**
     * Get customer group code.
     *
     * @return string
     */
    public function getCustomerGroupCode(): string
    {
        try {
            // Using customerSession to get customer group id
            // Created ticket https://jira.corp.adobe.com/browse/AC-6741 for UserContextInterface
            $customerGroupId = $this->customerSession->getCustomerGroupId();
        } catch (LocalizedException $e) {
            $customerGroupId = GroupInterface::NOT_LOGGED_IN_ID;
        }

        // sha1 is used in exported data, so we need to pass the same format here
        // https://github.com/magento-commerce/commerce-data-export-ee/blob/302dbb6216373110a8d2a3e636d6d8924f5e0f96/ProductOverrideDataExporter/etc/query.xml#L13
        return \sha1((string)$customerGroupId);
    }

    /**
     * Get API Key from Services Connector configuration
     *
     * @return string|null
     */
    public function getApiKey(): ?string
    {
      return $this->scopeConfig->getValue(self::CONFIG_PATH_API_KEY);
    }
}

==> magento-module-data-services-graphql-1.3.0.zip: Model/Resolver/StorefrontInstanceContext.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Magento\DataServicesGraphQl\Model\Resolver;

use Magento\DataServices\Model\VersionFinderInterface;
use Magento\Framework\App\CacheInterface;
use Magento\Framework\GraphQl\Config\Element\Field;
use Magento\Framework\GraphQl\Query\Resolver\ContextInterface;
use Magento\Framework\GraphQl\Query\ResolverInterface;
use Magento\Framework\GraphQl\Schema\Type\ResolveInfo;
use Magento\Framework\UrlInterface;
use Magento\ServicesId\Model\ServicesConfigInterface;
use Magento\Customer\Api\Data\GroupInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Customer\Model\Session;
use Magento\Framework\App\Config\ScopeConfigInterface;

/**
 * Class that implements the dataServicesStorefrontInstanceContext resolver
 */
class StorefrontInstanceContext implements ResolverInterface
{

    /**
     * Extension constants
     */
    const CATALOG_EXPORTER_MODULE_NAME = 'Magento/CatalogDataExporter';
    const CATALOG_EXPORTER_PACKAGE_NAME = 'magento/saas-export';
    const CATALOG_EXPORTER_VERSION_CACHE_TAG = 'catalog_exporter_extension_version';

    /**
     * Service Connector Config Paths
     *
     * @var string
     */
    private const CONFIG_PATH_API_KEY = 'services_connector/services_connector_integration/production_api_key';

    /**
     * @var VersionFinderInterface
     */
    private $versionFinder;

    /**
     * @var ServicesConfigInterface
     */
    private $servicesConfig;

    /**
     * @var CacheInterface
     */
    private $cache;

    /**
     * @var Session
     */
    private Session $customerSession;

    /**
     * @var ScopeConfigInterface
     */
    private ScopeConfigInterface $scopeConfig;

    /**
     * StorefrontInstanceContext constructor.
     * @param VersionFinderInterface $versionFinder
     * @param ServicesConfigInterface $servicesConfig
     * @param CacheInterface $cache
     * @param Session $customerSession
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        VersionFinderInterface $versionFinder,
        ServicesConfigInterface $servicesConfig,
        CacheInterface $cache,
        Session $customerSession,
        ScopeConfigInterface $scopeConfig,
    ) {
        $this->versionFinder = $versionFinder;
        $this->servicesConfig = $servicesConfig;
        $this->cache = $cache;
        $this->customerSession = $customerSession;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @param Field $field
     * @param ContextInterface $context
     * @param ResolveInfo $info
     * @param array|null $value
     * @param array|null $args
     * @return array
     */
    public function resolve(
        Field $field,
        $context,
        ResolveInfo $info,
        ?array $value = null,
        ?array $args = null
    ) {
        $store = $context->getExtensionAttributes()->getStore();
        return [
            'environment_id' => $this->servicesConfig->getEnvironmentId(),
            'environment' => $this->servicesConfig->getEnvironmentType(),
            'ims_org_id' => $this->servicesConfig->getImsOrganizationId(),
            'store_url' => $store->getBaseUrl(UrlInterface::URL_TYPE_WEB),
            'website_id' => $store->getWebsiteId(),
            'website_code' => $store->getWebsite()->getCode(),
            'store_id' => $store->getGroup()->getId(),
            'store_code' => $store->getGroup()->getCode(),
            'store_view_id' => $store->getId(),
            'store_view_code' => $store->getCode(),
            'website_name' => $store->getWebsite()->getName(),
            'store_name' => $store->getGroup()->getName(),
            'store_view_name' => $store->getName(),
            'catalog_extension_version' => $this->getCatalogExtensionVersion(),
            'base_currency_code' => $store->getBaseCurrencyCode(),
            'store_view_currency_code' => $store->getCurrentCurrency()->getCode(),
            'customer_group' => $this->getCustomerGroupCode(),
            'api_key' => $this->getApiKey()
        ];
    }

    /**
     * Return catalog extension version
     *
     * @return string|null
     */
    private function getCatalogExtensionVersion(): ?string
    {
        $catalogVersion = $this->cache->load(self::CATALOG_EXPORTER_VERSION_CACHE_TAG);
        if (!$catalogVersion) {
            $catalogVersion = $this->versionFinder->getVersionFromComposer(self::CATALOG_EXPORTER_PACKAGE_NAME)
                ?: $this->versionFinder->getVersionFromFiles(
                    self::CATALOG_EXPORTER_MODULE_NAME,
                    self::CATALOG_EXPORTER_PACKAGE_NAME
                );
            $this->cache->save($catalogVersion, self::CATALOG_EXPORTER_VERSION_CACHE_TAG);
        }

        return $catalogVersion ?? null;
    }

    /**
     * Get customer group code.
     *
     * @return string
     */
    public function getCustomerGroupCode(): string
    {
        try {
            // Using customerSession to get customer group id
            // Created ticket https://jira.corp.adobe.com/browse/AC-6741 for UserContextInterface
            $customerGroupId = $this->customerSession->getCustomerGroupId();
        } catch (LocalizedException $e) {
            $customerGroupId = GroupInterface::NOT_LOGGED_IN_ID;
        }

        // sha1 is used in exported data, so we need to pass the same format here
        // https://github.com/magento-commerce/commerce-data-export-ee/blob/302dbb6216373110a8d2a3e636d6d8924f5e0f96/ProductOverrideDataExporter/etc/query.xml#L13
        return \sha1((string)$customerGroupId);
    }

    /**
     * Get API Key from Services Connector configuration
     *
     * @return string|null
     */
    public function getApiKey(): ?string
    {
      return $this->scopeConfig->getValue(self::CONFIG_PATH_API_KEY);
    }
}
